from __future__ import unicode_literals

from django.apps import AppConfig


class BomConfig(AppConfig):
    name = 'bom'
    mouser_api_key = None